import storage from '@/modules/storage.module';

interface ISendLeadParams {
  [key: string]: string;
}

const ErrorsCodes: any = {
  31: 'Объект не найден'
}

const checkErrors = (code: number, field: string, error: string = '') => {
  let errorText = error;
  if(typeof ErrorsCodes[code] !== 'undefined') {
    // return ErrorsCodes[code];
    errorText = ErrorsCodes[code];
  }

  return `${code} (${field}): ${errorText}`;
}

export function sendLead(data: ISendLeadParams) {
  return new Promise((resolve, reject) => {
    const xhr = new XMLHttpRequest();

    xhr.onreadystatechange = function () {
      if (xhr.readyState === 4) {
        if (xhr.status === 200) {
          resolve(xhr.responseText);
        } else {
          const parsing = JSON.parse(xhr.responseText)
          if(parsing.code && parsing.message && parsing.field) {
            const { code, message, field } = parsing;
            reject(checkErrors(code, field, message))
          } else {
            reject('Произошла непредвиденная ошибка, мы вкурсе данной проблемы, и уже занимаемся ее устранением')
          }
        }
      }
    };
  
    xhr.open('POST', 'https://dev.console.admefine.ru/api/mediaplan/lead_incoming', true);
    xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
    xhr.send(JSON.stringify(makeData(data)));
  })
}

const makeData = (data: ISendLeadParams) => {
  const getUTM = storage.getAllStorage();
  const sendData = {...data, utm: getUTM};
  return sendData;
}